@@ -334,7 +334,7 @@ nmObjGet.covLvl <- function(x, ...) {
 }
 #attr(nmObjGet.dataSav, "desc") <- "data that focei sees for optimization"
 
-.dataMergeStub <- function(obj) {
+.dataMergeStub <- function(obj, preferFit=TRUE) {
   .env      <- obj$env
   .origData <- obj$origData
   .origData$nlmixrRowNums <- seq_len(nrow(.origData))
@@ -375,7 +375,11 @@ nmObjGet.covLvl <- function(x, ...) {
   names(.origData)[.wid] <- "ID"
   .fitData$nlmixrRowNums <- .env$.rownum
   .share <- setdiff(intersect(names(.origData), names(.fitData)), c("ID", "nlmixrRowNums"))
-  .fitData <- .fitData[, !(names(.fitData) %in% .share)]
+  if (preferFit) {
+    .origData <- .origData[, !(names(.origData) %in% .share)]
+  } else {
+    .fitData <- .fitData[, !(names(.fitData) %in% .share)] 
+  }
   if (inherits(.fitData$ID, "factor")) {
     .origData$ID <- factor(paste(.origData$ID), levels = levels(.fitData$ID))
   }
@@ -386,46 +390,89 @@ nmObjGet.covLvl <- function(x, ...) {
 #' @export
 nmObjGetData.dataMergeLeft <- function(x, ...) {
   .obj <- x[[1]]
-  .lst <- .dataMergeStub(.obj)
+  .lst <- .dataMergeStub(.obj, preferFit=FALSE)
   .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.x=TRUE)
   .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
   .ret
 }
-attr(nmObjGetData.dataMergeLeft, "desc") <- "left join between original and fit dataset"
+attr(nmObjGetData.dataMergeLeft, "desc") <- "left join between original and fit dataset (prefer columns in original dataset)"
 
 #' @rdname nmObjGetData
 #' @export
 nmObjGetData.dataMergeRight <- function(x, ...) {
   .obj <- x[[1]]
-  .lst <- .dataMergeStub(.obj)
+  .lst <- .dataMergeStub(.obj, preferFit=FALSE)
   .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.y=TRUE)
   .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
   .ret
 }
-attr(nmObjGetData.dataMergeRight, "desc") <- "right join between original and fit dataset"
+attr(nmObjGetData.dataMergeRight, "desc") <- "right join between original and fit dataset (prefer columns in original dataset)"
 
 #' @rdname nmObjGetData
 #' @export
 nmObjGetData.dataMergeInner <- function(x, ...) {
   .obj <- x[[1]]
-  .lst <- .dataMergeStub(.obj)
+  .lst <- .dataMergeStub(.obj, preferFit=FALSE)
   .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"))
   .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
   .ret
 }
-attr(nmObjGetData.dataMergeRight, "desc") <- "inner join between original and fit dataset"
+attr(nmObjGetData.dataMergeRight, "desc") <- "inner join between original and fit dataset (prefer columns in original dataset)"
 
 #' @rdname nmObjGetData
 #' @export
 nmObjGetData.dataMergeFull <- function(x, ...) {
   .obj <- x[[1]]
-  .lst <- .dataMergeStub(.obj)
+  .lst <- .dataMergeStub(.obj, preferFit=FALSE)
   .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.x=TRUE, all.y=TRUE)
   .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
   .ret
 }
-attr(nmObjGetData.dataMergeFull, "desc") <- "full join between original and fit dataset"
+attr(nmObjGetData.dataMergeFull, "desc") <- "full join between original and fit dataset (prefer columns in fit dataset)"
 
+#' @rdname nmObjGetData
+#' @export
+nmObjGetData.fitMergeLeft <- function(x, ...) {
+  .obj <- x[[1]]
+  .lst <- .dataMergeStub(.obj, preferFit=FALSE)
+  .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.x=TRUE)
+  .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
+  .ret
+}
+attr(nmObjGetData.fitMergeLeft, "desc") <- "left join between original and fit dataset (prefer columns in fit dataset)"
+
+#' @rdname nmObjGetData
+#' @export
+nmObjGetData.fitMergeRight <- function(x, ...) {
+  .obj <- x[[1]]
+  .lst <- .dataMergeStub(.obj, preferFit=TRUE)
+  .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.y=TRUE)
+  .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
+  .ret
+}
+attr(nmObjGetData.fitMergeRight, "desc") <- "right join between original and fit dataset (prefer columns in fit dataset)"
+
+#' @rdname nmObjGetData
+#' @export
+nmObjGetData.fitMergeInner <- function(x, ...) {
+  .obj <- x[[1]]
+  .lst <- .dataMergeStub(.obj, preferFit=TRUE)
+  .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"))
+  .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
+  .ret
+}
+attr(nmObjGetData.fitMergeRight, "desc") <- "inner join between original and fit dataset (prefer columns in fit dataset)"
+
+#' @rdname nmObjGetData
+#' @export
+nmObjGetData.fitMergeFull <- function(x, ...) {
+  .obj <- x[[1]]
+  .lst <- .dataMergeStub(.obj, preferFit=TRUE)
+  .ret <- merge(.lst[[1]], .lst[[2]], by=c("ID", "nlmixrRowNums"), all.x=TRUE, all.y=TRUE)
+  .ret <- .ret[, names(.ret) != "nlmixrRowNums"]
+  .ret
+}
+attr(nmObjGetData.fitMergeFull, "desc") <- "full join between original and fit dataset (prefer columns in fit dataset)"
 
 #' @rdname nmObjGet
 #' @export
